<?php
/**
 * WooCommerce Price Robot - Products General Settings
 *
 * @version 1.1.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Price_Robot_Settings_General' ) ) :

class Alg_WC_Price_Robot_Settings_General {

	/**
	 * Constructor.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function __construct() {
		$this->id   = '';
		$this->desc = __( 'General', 'price-robot-for-woocommerce' );
		add_filter( 'woocommerce_get_sections_alg_price_robot',              array( $this, 'settings_section' ), 1 );
		add_filter( 'woocommerce_get_settings_alg_price_robot_' . $this->id, array( $this, 'get_settings' ), 1 );
	}

	/**
	 * settings_section.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function settings_section( $sections ) {
		$sections[ $this->id ] = $this->desc;
		return $sections;
	}

	/**
	 * get_settings.
	 *
	 * @version 1.1.0
	 * @since   1.0.0
	 */
	function get_settings() {
		$settings = array(
			array(
				'title'     => __( 'Price Robot General Options', 'price-robot-for-woocommerce' ),
				'type'      => 'title',
				'id'        => 'alg_price_robot_general_options',
			),
			array(
				'title'     => __( 'Automatic Pricing', 'price-robot-for-woocommerce' ),
				'desc'      => __( 'Enable', 'price-robot-for-woocommerce' ),
				'desc_tip'  => sprintf(
					__( 'This will change products prices on frontend. If disabled, will work in Advisor mode. Visit <a href="%s">WooCommerce Products page</a> to enable the robot on per product basis.', 'price-robot-for-woocommerce' ),
					admin_url( 'edit.php?post_type=product' )
				),
				'id'        => 'alg_price_robot_general_auto_pricing_enabled',
				'default'   => 'yes',
				'type'      => 'checkbox',
			),
			array(
				'title'     => __( 'Debug Column in WooCommerce Admin Products View', 'price-robot-for-woocommerce' ),
				'desc'      => __( 'Enable', 'price-robot-for-woocommerce' ),
				'id'        => 'alg_price_robot_general_admin_products_debug_enabled',
				'default'   => 'no',
				'type'      => 'checkbox',
			),
			array(
				'title'     => __( 'Data Update Schedule', 'price-robot-for-woocommerce' ),
				'desc'      => '<a href="' . add_query_arg( 'get_orders_manual', 'yes' ) . '">' . __( 'Update Data Now', 'price-robot-for-woocommerce' ) . '</a>',
				'desc_tip'  => alg_wc_price_robot_get_data_last_updated_message(),
				'id'        => 'alg_price_robot_general_admin_crons_update',
				'default'   => 'daily',
				'type'      => 'select',
				'options'   => alg_get_cron_update_intervals(),
			),
			array(
				'title'     => __( 'Display as Sale', 'price-robot-for-woocommerce' ),
				'desc'      => __( 'Display as sale if robot price is lower than original price.', 'price-robot-for-woocommerce' ),
				'id'        => 'alg_price_robot_general_display_as_sale',
				'default'   => 'yes',
				'type'      => 'checkbox',
			),
			array(
				'title'     => __( 'Variable Products', 'price-robot-for-woocommerce' ),
				'desc'      => __( 'Treat variations as single product.', 'price-robot-for-woocommerce' ),
				'desc_tip'  => __( 'Makes sense if you are going to have same (equal) prices for all variations of a variable product.', 'price-robot-for-woocommerce' )
				       . ' ' . __( 'You may need to clear transients after changing this option.', 'price-robot-for-woocommerce' ),
				'id'        => 'alg_price_robot_general_variable_as_single',
				'default'   => 'no',
				'type'      => 'checkbox',
			),
			array(
				'type'      => 'sectionend',
				'id'        => 'alg_price_robot_general_options',
			),
		);
		return $settings;
	}

}

endif;

return new Alg_WC_Price_Robot_Settings_General();
