<?php
/**
 * WooCommerce Price Robot - Abstract
 *
 * @version 1.1.0
 * @since   1.0.0
 * @author  Algoritmika Ltd.
 */

if ( ! defined( 'ABSPATH' ) ) exit; // Exit if accessed directly

if ( ! class_exists( 'Alg_WC_Price_Robot_Abstract' ) ) :

class Alg_WC_Price_Robot_Abstract {

	public $id;
	public $title;
	public $desc;
	public $priority;

	/**
	 * Constructor.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function __construct() {
		add_filter( 'woocommerce_get_sections_alg_price_robot',              array( $this, 'settings_section' ), $this->priority );
		add_filter( 'woocommerce_get_settings_alg_price_robot_' . $this->id, array( $this, 'get_settings' ), $this->priority );
		if ( 'yes' === get_option( 'alg_price_robot_' . $this->id . '_enabled', 'yes' ) ) {
			add_filter( 'alg_woocommerce_price_robot', array( $this, 'get_price' ), $this->priority, 3 );
		}
	}

	/**
	 * settings_section.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function settings_section( $sections ) {
		$sections[ $this->id ] = $this->title;
		return $sections;
	}

	/**
	 * get_settings.
	 *
	 * @version 1.0.0
	 * @since   1.0.0
	 */
	function get_settings() {
		$settings = array(
			array(
				'title'     => $this->title . ' ' . __( 'Options', 'price-robot-for-woocommerce' ),
				'desc'      => $this->desc,
				'type'      => 'title',
				'id'        => 'alg_price_robot_' . $this->id . '_enable_options',
			),
			array(
				'title'     => $this->title,
				'desc'      => '<strong>' . __( 'Enable', 'price-robot-for-woocommerce' ) . '</strong>',
				'id'        => 'alg_price_robot_' . $this->id . '_enabled',
				'default'   => 'yes',
				'type'      => 'checkbox',
			),
			array(
				'type'      => 'sectionend',
				'id'        => 'alg_price_robot_' . $this->id . '_enable_options',
			),
		);
		return $settings;
	}

}

endif;
